
# Project Title

A simple python data structures packaage


## Installation

Install the package with pip

```bash
  pip install simplepyds
```

### Usage Example

```python
from simplepyds.Tree import BinarySearchTree

bst = BinarySearchTree()
```
    
## Documentation

### Trees

#### Binary Search Tree

### Lists

#### Singly Linked List
#### Doubly Linked List

### Hash Tables


## License

[MIT](https://choosealicense.com/licenses/mit/)


## Authors

- [@TheophilusNenhanga](https://github.com/TheophilusNenhanga)

